@@ -1,9 +1,5 @@
-try:
-    from widgets import FullScreenTextarea
-except ImportError:
-    pass
-
-version = (1, 0, 8)
+from widgets import FullScreenTextarea
+version = (1, 1)
 
 
 def get_version():
